@@ -28,16 +28,19 @@
  */
 
 void box_alert( GtkWidget *par );
-void box_info( GtkWidget *par, const char *top, const char *sub, ... );
+void box_info( GtkWidget *par, const char *top, const char *sub, ... )
+	__attribute__((format(printf, 3, 4)));
 iDialog *box_yesno( GtkWidget *par, 
 	iWindowFn okcb, iWindowFn cancelcb, void *client, /* Call client */
 	iWindowNotifyFn nfn, void *sys,			  /* Call parent */
 	const char *yes_label, 
-	const char *top, const char *sub, ... );
+	const char *top, const char *sub, ... )
+	__attribute__((format(printf, 9, 10)));
 void box_savenosave( GtkWidget *par, 
 	iWindowFn save, iWindowFn nosave, void *client,   /* Call client */
 	iWindowNotifyFn nfn, void *sys,			  /* Call parent */
-	const char *top, const char *sub, ... );
+	const char *top, const char *sub, ... )
+	__attribute__((format(printf, 8, 9)));
 void box_about( GtkWidget *par );
 void box_help( GtkWidget *par, const char *name );
 
@@ -132,20 +135,10 @@ typedef struct _Imageheader {
 	iDialog parent;
 
 	Conversion *conv;
-
-	GtkWidget *xsize;
-	GtkWidget *ysize;
-	GtkWidget *bands;
-	GtkWidget *bbits;
-	GtkWidget *fmt;
-	GtkWidget *coding;
-	GtkWidget *type;
-	GtkWidget *xres;
-	GtkWidget *yres;
-	GtkWidget *xoff;
-	GtkWidget *yoff;
+	GtkWidget *swin_fields;
+	GtkWidget *fields;
+	GtkSizeGroup *group;
 	GtkWidget *history;
-	GtkWidget *filename;
 } Imageheader;
 
 typedef struct _ImageheaderClass {
@@ -222,7 +215,8 @@ typedef struct _SplashClass {
 
 GtkType splash_get_type( void );
 void splash_updatev( Splash *splash, const char *fmt, va_list ap );
-void splash_update( Splash *progress, const char *fmt, ... );
+void splash_update( Splash *progress, const char *fmt, ... )
+	__attribute__((format(printf, 2, 3)));
 Splash *splash_new( void );
 
 /* Font chooser window.
