@@ -40,7 +40,7 @@ iregion_instance_destroy( iRegionInstance *instance )
 {
 	instance->image_class.type = ELEMENT_NOVAL;
 	instance->image_class.ele = (void *) 8;
-	IM_FREEF( imageinfo_destroy_nonheap, instance->ii );
+	MANAGED_UNREF( instance->ii );
 	instance->classmodel = NULL;
 	instance->iregiongroup = NULL;
 	heap_unregister_element( reduce_context->heap, &instance->image_class );
@@ -83,9 +83,9 @@ iregion_instance_update( iRegionInstance *instance, PElement *root )
 	instance->area.width = width;
 	instance->area.height = height;
 
-	IM_FREEF( imageinfo_destroy_nonheap, instance->ii );
+	MANAGED_UNREF( instance->ii );
 	instance->ii = value;
-	imageinfo_dup_nonheap( value );
+	MANAGED_REF( value );
 
 	PEPOINTE( &image_class, &instance->image_class );
 	PEPUTPE( &image_class, &image );
@@ -145,37 +145,29 @@ iregion_generate_caption( iObject *iobject )
 	iRegion *iregion = IREGION( iobject );
 	iImage *iimage = IIMAGE( iregion );
 	const int nimages = g_slist_length( CLASSMODEL( iregion )->iimages );
-	Expr *expr;
-	gboolean result;
+	BufInfo *buf = &iimage->caption_buffer;
 	gboolean first;
-	Compile *compile;
 
-	if( !HEAPMODEL( iregion )->row ||
-		!(expr = HEAPMODEL( iregion )->row->expr) || 
-		!heap_isclass( &expr->root, &result ) || !result )
-		return( _( "No image" ) );
-
-	compile = PEGETCLASSCOMPILE( &expr->root );
-	buf_rewind( &iimage->caption_buffer );
-	symbol_qualified_name( compile->sym, &iimage->caption_buffer );
-	buf_appendf( &iimage->caption_buffer, " " );
+	buf_rewind( buf );
+	heapmodel_name( HEAPMODEL( iregion ), buf );
+	buf_appendf( buf, " " );
 	/* Expands to (eg.) "Region on A1 at (10, 10), size (50, 50)"
 	 */
-	buf_appendf( &iimage->caption_buffer, _( "on" ) );
-	buf_appendf( &iimage->caption_buffer, " " );
+	buf_appendf( buf, _( "on" ) );
+	buf_appendf( buf, " " );
 	if( nimages > 1 )
-		buf_appendf( &iimage->caption_buffer, "[" );
+		buf_appendf( buf, "[" );
 	first = TRUE;
 	slist_map2( CLASSMODEL( iregion )->iimages,
 		(SListMap2Fn) iregion_generate_caption_sub, iregion, &first );
 	if( nimages > 1 )
-		buf_appendf( &iimage->caption_buffer, "]" );
-	buf_appendf( &iimage->caption_buffer, " " );
-	buf_appendf( &iimage->caption_buffer, _( "at (%d, %d), size (%d, %d)" ),
+		buf_appendf( buf, "]" );
+	buf_appendf( buf, " " );
+	buf_appendf( buf, _( "at (%d, %d), size (%d, %d)" ),
 		iregion->instance.area.left, iregion->instance.area.top,
 		iregion->instance.area.width, iregion->instance.area.height );
 
-	return( buf_all( &iimage->caption_buffer ) );
+	return( buf_all( buf ) );
 }
 
 static void
@@ -208,6 +200,12 @@ iregion_done_cb( iWindow *iwnd, void *client, iWindowNotifyFn nfn, void *sys )
 	nfn( sys, IWINDOW_TRUE );
 }
 
+static View *
+iregion_view_new( Model *model, View *parent )
+{
+	return( iregionview_new() );
+}
+
 /* Pop up a iregion edit box. Shared with iarrow.c.
  */
 void 
@@ -242,7 +240,7 @@ iregion_edit( GtkWidget *parent, Model *model )
 		iwindow_true_cb, NULL, NULL, classmodel );
 	idialog_add_ok( IDIALOG( ss ), 
 		iregion_done_cb, _( "Set Region" ) );
-	idialog_set_parent( IDIALOG( ss ), GTK_WIDGET( parent ) );
+	iwindow_set_parent( IWINDOW( ss ), GTK_WIDGET( parent ) );
 	idialog_set_iobject( IDIALOG( ss ), IOBJECT( model ) );
 	idialog_set_pinup( IDIALOG( ss ), TRUE );
 	iwindow_build( IWINDOW( ss ) );
@@ -342,7 +340,7 @@ iregion_update_heap( Heapmodel *heapmodel )
 		 */
 		area = instance->area;
 
-		/* Look for the base instance, and update from that.
+		/* Look for the base instance and update from that.
 		 */
 		if( !class_get_exact( &expr->root, 
 			IOBJECT( heapmodel )->name, &pe ) )
@@ -467,7 +465,7 @@ iregion_class_init( iRegionClass *class )
 
 	icontainer_class->parent_add = iregion_parent_add;
 
-	model_class->view_new = iregionview_new;
+	model_class->view_new = iregion_view_new;
 	model_class->edit = iregion_edit;
 	model_class->save = iregion_save;
 	model_class->load = iregion_load;
@@ -516,14 +514,3 @@ iregion_get_type( void )
 
 	return( type );
 }
-
-Classmodel *
-iregion_new( Rhs *rhs )
-{
-	iRegion *iregion;
-
-	iregion = IREGION( g_object_new( TYPE_IREGION, NULL ) );
-	icontainer_child_add( ICONTAINER( rhs ), ICONTAINER( iregion ), -1 );
-
-	return( CLASSMODEL( iregion ) );
-}
